Multidimensional Data — GDA Toolbox v1.0 Manual

# Multidimensional Data

## Embedded Data

Typically, data lies in some Cartesian space, \(\mathbb{R}^d\).

If your data can be described as \(N\) points lying in \(\mathbb{R}^d\), typically stored as an \(N \times d\) `numpy.ndarray`, then then you probably want to use our `multidim.PointCloud` class to analyze.

`multidim.PointCloud`(data_array[, …]) | PointCloud is a class for embedded, weighted simplicial complexes.
`multidim.covertree.CoverTree`(pointcloud[, …]) | An efficient and convenient implementation of the “Cover Tree with Friends” algorithm.

## Abstract Data

Sometimes, the data under consideration does not live in a specific ambient space.

`multidim.SimplicialComplex`([stratum]) | A class for abstract weighted simplicial complexes.
`multidim.SimplexStratum`(cell_complex, dim) | SimplexStratum is a thin class for calling `Simplex` objects of a certain dimension from a SimplicialComplex.
`multidim.Simplex`(cellcomplex, dim, index) | This class is a convenient container to access the data in the pd DataFrame stratum[dim] of a SimplicialComplex.

### Table of Contents

- Multidimensional Data
  - Embedded Data
  - Abstract Data

#### Previous topic

COPYRIGHT NOTICE

#### Next topic

multidim.PointCloud